import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback
} from 'reactstrap';

import ValidatorService from '../../services/validator'

class TextField extends Component {
    static propTypes = {
        control: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        value: PropTypes.string.isRequired,
        onChange: PropTypes.func.isRequired,
        placeholder: PropTypes.func.isRequired,
        disabled: PropTypes.bool,
        required: PropTypes.bool,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        password: PropTypes.bool
    };

    static defaultProps = {
        maxLength: 50,
        minLength: 2,
        password: false,
        disabled: false,
        required: true
    };

    constructor(props) {
        super(props);
        this.state = {dirty: false};
    }

    validateInput() {
        if (!this.state.dirty) {
            return null;
        }
        const {value, maxLength, minLength} = this.props;
        return ValidatorService.validateText(value, maxLength, minLength) ? 'success' : 'error';
    }

    handleChange({target}) {
        if (this.props.value === target.value) {
            return;
        }
        this.setState({dirty: true});
        this.props.onChange({target});
    }

    render() {
        const {
            control,
            label,
            value,
            maxLength,
            minLength,
            password,
            disabled,
            required,
            placeholder
        } = this.props;
        return (
            <FormGroup
                controlId={control}
                validationState={this.validateInput()}
            >
                {
                    label && (
                        <Label>
                            &nbsp;
                            {label}
                            &nbsp;
                        </Label>
                    )
                }
                <Input
                    id={control}
                    type={password ? 'password' : 'text'}
                    value={value}
                    placeholder={placeholder}
                    required={required}
                    disabled={disabled}
                    maxLength={maxLength}
                    minLength={minLength}
                    onChange={e => this.handleChange(e)}
                />
                <FormFeedback/>
            </FormGroup>
        );
    }
}

export default TextField;