import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback, UncontrolledTooltip
} from 'reactstrap';
import {flexC, flexR, linkStyle, noPadding, small, toolTip, padding, toolTipIcon, smallAlt} from '../common/styles/index'
class CheckBoxField extends Component {
    static propTypes = {
        onChange: PropTypes.func.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        linkTo: PropTypes.shape({
            label: PropTypes.string,
            url: PropTypes.string,
            target: PropTypes.string
        }),
        value: PropTypes.string,
        type: PropTypes.string.isRequired,
        helpText: PropTypes.string,
        disabled: PropTypes.bool,
        error: PropTypes.shape(),
        inline: PropTypes.bool
    };

    static defaultProps = {
        inline: false,
        value: null,
        helpText: null,
        disabled: false,
        error: {
            status: null
        },
        linkTo: null
    };

    handleChange({target}) {
        if (this.props.value === target.checked) {
            return;
        }
        this.props.onChange({target});
    }

    render() {
        const {
            name, label, value, type, helpText, disabled, error, linkTo, inline
        } = this.props;
        const flex = inline? {...flexR} : flexC
        return (
            <div style={{...flex, ...{justifyContent: 'center'}}}>
            <FormGroup
                style={{...flexC,...{paddingBottom: '1rem'},...{marginRight: '3rem'}}}>
                <Label
                    style={{...small, ...noPadding, ...flexR,...padding,...{justifyContent: 'center'}}}>
                    <p
                        style={noPadding}>
                        {label}
                    </p>
                    {helpText && (
                        <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                            {String.fromCharCode(0x24D8)}
                        </p>
                    )}
                </Label>
                <div style={{...{justifyContent: 'center'}, ...{display:'flex'}}}>
                    <Input
                            style={{...{position: 'static'}, ...{marginLeft: '0px'}}}
                        valid={error.status === 'valid' ? true : null}
                        invalid={error.status === 'invalid' ? true : null}
                        id={name}
                        name={name}
                        type={type}
                        checked={value}
                        disabled={disabled}
                        onChange={e => this.handleChange(e)}
                    />
                </div>
                <div>


                    {linkTo && (
                        <a
                            href={linkTo.url}
                            target={linkTo.target}
                            style={linkStyle}
                        >
                            {linkTo.label}
                        </a>
                    )}
                    <FormFeedback valid={error.status === 'valid' ? true : null}>
                        {error.message}
                    </FormFeedback>
                {helpText && (
                    <UncontrolledTooltip placement="top" target={'ref'+name}
                                         style={toolTip}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
                </div>
            </FormGroup>
            </div>
        );
    }
}

export default CheckBoxField;
